/*	IMPLEMENT NEW DWP METHOD OF IMPUTING SCP
*	
*	Prepared by Hannah Randolph and Chirsty McFadyen
*
*	Started 13 January 2025
*	Modified 25 March 2025
*
*	PURPOSE:
*	Takes DWP's new methodology for imputing SCP in the 2023-24 FRS data and 
*	implements it in 2022-23 to see if it would have changed the 
*	Scottish child poverty statistics.
*
*	NB: Extension to under-16s happened mid-month; assume any household 
*	surveyed in Nov22 or later is eligible
*	
*/
******************************************************************************** 

log using "${projdir}\out\imputeSCP", replace 

qui {

******************************************************************************** 
***	NUMBER AND AGES OF CHILDREN IN HH - HH
********************************************************************************

*	Load child data
use "${projdir}\data\FRS\child.dta", clear 
rename *, lower 
keep sernum benunit age 

*	Rank children in benunit by age 
gsort sernum benunit -age		// sort children in benunit in descending order of age (oldest first)
bysort sernum benunit : gen rank = _n

*	Reshape wide to get hh level with age1, age2, etc. containing each child's age 
reshape wide age, i(sernum benunit) j(rank)

*	Check that sernum x benunit uniquely identifies an observation 
unique sernum benunit
assert `r(N)'==`r(unique)'

rename sernum benunit, upper 

*	Get number of children - merge with benunit data 
merge 1:1 SERNUM BENUNIT using "${projdir}\data\FRS\benunit.dta", keepusing(depchldb)
drop if _merge==2 
assert _merge==3 	// all children should match to benunit data
drop _merge 

*	Check that all dependent children have ages listed 
egen numdepch = rownonmiss(age1 age2 age3 age4 age5 age6 age7)		// count non-missing child ages for each benunit 
assert numdepch==depchldb		// # dependent children should match # children's ages 

*	Save tempfile 
tempfile childages
save `childages', replace 

******************************************************************************** 
// SET UP ANALYSIS PARAMETERS AND DATA
******************************************************************************** 

noi di as result "Number of repetitions: " ${reps}

* Get SCP information from benefits data 
use "${projdir}\data\FRS\benefits.dta", clear
keep if inlist(BENEFIT, 112, 95, 91, 90, 14, 4, 19, 16)
gen SCP_orig = 1 if BENEFIT==112 
bysort SERNUM BENUNIT SCP_orig : egen SCPamt_orig = total(BENAMT)
replace SCPamt_orig = 0 if SCP_orig!=1
gen UC = (BENEFIT==95)
gen CTC = (BENEFIT==91)
gen WTC = (BENEFIT==90)
gen JSA = (BENEFIT==14)
gen PC = (BENEFIT==4)
gen IS = (BENEFIT==19)
gen ESA = (BENEFIT==16)
order SERNUM BENUNIT SCPamt_orig SCP_orig 
collapse (sum) SCPamt_orig SCP_orig UC CTC WTC JSA PC IS ESA , by(SERNUM BENUNIT)
ds SCP_orig-ESA
foreach var in `r(varlist)' {
	replace `var' = 1 if `var'>0 & !missing(`var')
}
unique SERNUM BENUNIT
assert `r(N)'==`r(unique)' 		// check that each benunit has only one record 

tempfile benefits 
save `benefits'

* Open benunit data 
use "${projdir}\data\FRS\benunit.dta", clear
keep SERNUM BENUNIT GROSS4 kid* fsmbu

* Merge in SCP information gotten from benefits.dta above 
merge 1:1 SERNUM BENUNIT using `benefits', gen(_mben)
assert _mben!=2 		// no non-matches in using 
drop _mben 

* Get region, survey month information from household data 
merge m:1 SERNUM using "${projdir}\data\FRS\househol.dta", keepusing(GVTREGNO MNTHCODE) gen(_mhh)
assert _mhh==3
drop _mhh 

* Get child age information from file created in prep.do
merge 1:1 SERNUM BENUNIT using `childages', gen(_mchage)
drop if _mchage==2
assert _mchage==3 if (kid04 + kid510 + kid1115 > 0)		// all benunits with children should match 
drop _mchage kid* numdepch

rename *, lower 

* Keep only Scottish benefit units 
assert gvtregno==12 if scp_orig==1 	// check that all benunits previously imputed as receiving SCP are in Scotland
keep if gvtregno==12

* Check identifying variables 
unique sernum benunit
assert `r(N)'==`r(unique)'		// sernum x benunit should uniquely identify observations

******************************************************************************** 
// DATA CLEANING AND NEW VARIABLES 
******************************************************************************** 

// Number of kids in different age groups 
gen kid05 = 0 
gen kid615 = 0
forvalues k = 1/7 {
	replace kid05 = kid05 + 1 if (age`k'<6)
	replace kid615 = kid615 + 1 if (age`k'>=6 & age`k'<16)
}
label var kid05 "Number of children in benunit under 6"
label var kid615 "Number of children in benunit 6-15"
tab kid05 kid615
assert !missing(kid05) & !missing(kid615)		// shouldn't have missing kid information 
gen kid015 = kid05 + kid615

// Misc 
replace depchldb = 0 if missing(depchldb)		// no dep children in BU if this is missing 
gen postOct = inlist(mnthcode, 11, 12, 1, 2, 3)		// binary for interview post-Oct

// General SCP-related 
egen eligben = rowtotal(uc ctc wtc jsa pc is esa)		 
replace eligben = (eligben>0)						// binary for receiving qualifying benefits

gen scprate = . 
replace scprate = 20 if depchldb>0 & !postOct
replace scprate = 25 if depchldb>0 & postOct 		// what SCP rate per child should be based on date of interview 

gen numeligkids = kid05 if eligben==1 & !postOct 
replace numeligkids = kid05 + kid615 if eligben==1 & postOct	// number of eligible kids based on qualifying benefits and date of interview 

// Characteristics of original SCP receivers 
replace scp_orig = 0 if missing(scp_orig) 		// not receiving SCP in original FRS if this is missing
gen scprate_orig = scpamt_orig / depchldb 			// original rate per child implied by SCP amount reported in original FRS
gen numscpkids_orig = scpamt_orig / scprate 		// number of kids (presumably) originally receiving SCP 
replace numscpkids_orig = scpamt_orig / 25 if mnthcode==10		// correct for October interviews that incorrectly reported or were assigned £25 rate
gen scpkidwt = gross4 * numscpkids_orig 	// weight for kids receiving SCP in original FRS 

// Flag eligible households based on combined kids' ages and benefits 
gen u6eligkids = 0
replace u6eligkids = 1 if (kid05 > 0 & eligben==1)

gen u615eligkids = 0
replace u615eligkids = 1 if (kid615 > 0 & eligben==1 & postOct==1)

gen eligible = 1 if u6eligkids==1 | u615eligkids==1

// Weights for eligible kids
gen eligkid05wt = gross4 * kid05 if eligible==1 		// under 6s always eligible 
gen eligkid615wt = gross4 * kid615 if eligible==1 & postOct==1	// only count 6-15 if interviewed after Oct 22
gen eligkid015wt = gross4 * numeligkids if eligible==1

// Locals storing total populations for getting correct take-up rate 
sum eligkid05wt
local totwt05 = `r(sum)'

sum eligkid615wt 
local totwt615 = `r(sum)'

******************************************************************************** 
// LOOK AT PREVIOUS IMPUTATION 
********************************************************************************

*	Count # children receiving 
sum scpkidwt if scp_orig==1 
local scp_kids_orig = `r(sum)'
noi di "Number of kids in population receiving SCP in original FRS: " `scp_kids_orig'

*	Count # benunits receiving 
count if scp_orig==1 
local numbu_scp_orig = `r(N)'
sum gross4 if scp_orig==1 
local scp_bus_orig = `r(sum)'
noi di "Number of benunits in population receiving SCP in original FRS: " `scp_bus_orig' " benunits in " `numbu_scp_orig' " sample observations."

*	Get original cost 
gen scpcost_orig = scpamt_orig * gross4 * 52.14 
sum scpcost_orig 
local scp_cost_orig = `r(sum)'
noi di "Original estimated cost of SCP in 2022-23: " %6.2f `scp_cost_orig'/1000000 " million."

*	Check if any receiving incorrect amount based on date of interview + number of dependent kids (set aside change in age range for elig for now)
count if scprate_orig != scprate & scp_orig==1
noi di "Number of sample benunits receiving an SCP amount that doesn't match either their date of interview or their # dependent children: " `r(N)'
noi di "NB: This appears to be driven by incorrect reporting/imputation of £25/child in some cases and non-counting of children under 1 as eligible in others."
drop scprate_orig 

*	Check if any not receiving qualifying benefits 
replace eligben = (eligben>0)
count if eligben==0 & scp_orig==1 
noi di "Number of sample benunits originally receiving SCP but not receiving qualifying benefits: " `r(N)' " of " `numbu_scp_orig'

*	Check if any non-eligible children (on basis of age) receiving 
count if numeligkids==0 & scp_orig==1 
noi di "Number of sample benunits originally receiving SCP that don't have eligible children: " `r(N)' " of " `numbu_scp_orig'
count if numeligkids!=numscpkids_orig & scp_orig==1 
noi di "Number of sample benunits originally receiving SCP for at least one non-eligible child: " `r(N)' " of " `numbu_scp_orig'

******************************************************************************** 
// ACCOUNT FOR BRIDGING PAYMENTS
********************************************************************************

*	Identify households in Scotland receiving free school meals with kids 6-15
gen fsm = (fsmbu>0 & !missing(fsmbu) & kid615>0)

*	Calculate per-week amount per benunit for bridging payments (£)
gen SCPbpamt = kid615*12.47 if fsm==1

//	Store data to accommodate repetitions of the imputation methodology
tempfile prepdata
save `prepdata'		// save a temporary version of the data to reload on each replication 

******************************************************************************** 
// IMPLEMENT NEW IMPUTATION METHOD
********************************************************************************

noi di "Estimated number of eligible children represented in survey: " `totwt05' " kids aged 0-5 and " `totwt615' " kids aged 6-15."

forvalues rep = 1 / $reps {		// loop through imputation and re-calculation of poverty rates some # times 

	// OPEN DATA 
	use `prepdata', replace 

	// START WITH KIDS 0-5

	* generate random number for all households with at least one 0-5 year old
	gen randnum = runiform() if u6eligkids==1

	* generate flag for whether household is claiming SCP
	gen SCP = 0

	*generate variable for takeup to add each bu's kid weight to
	local takeupcount1 0

	*generate variable for takeup rate (bu kid weight / totwt04)
	local takeuprate1 0

	*sort by randum number value
	sort randnum, stable

	*create index for applying loop to hh with lowest random number
	local index 1

	*loop picks lowest eligible hh and adds its weight to counter until takeuprate1 = 0.97
	while `takeuprate1' < $tu05 {
		
		replace SCP = 1 if _n ==`index'
		local takeupcount1 = `takeupcount1' + eligkid05wt[`index']
		local takeuprate1 = `takeupcount1' / `totwt05'
		
		local ++index
		
	}

	// MOVE ON TO KIDS 6-15 
	
	*new random number for eligible households with 6-15 yos and no 0-5 yos - only after Nov 22
	gen randnum2 = runiform() if u615eligkids==1 & SCP!=1

	*calculate starting takeup rate for 5-15s since some were included in first takeup round
	sum eligkid615wt if SCP==1
	local takeupcount2 = `r(sum)'
	local takeuprate2 = `takeupcount2'/`totwt615'

	*sort by randum number value
	sort randnum2, stable

	*local index for counting
	local index2 1

	*loop picks lowest eligible hh and adds its weight to counter until takeuprate1 = 0.85
	while `takeuprate2' < $tu615 {
		
		replace SCP = 1 if _n ==`index2'
		local takeupcount2 = `takeupcount2' + eligkid615wt[`index2']
		local takeuprate2 = `takeupcount2' / `totwt615'
		
		local ++index2
		
	}

	display `takeuprate2'
	
	// ASSIGN SCP AMOUNT BASED ON # ELIGIBLE KIDS, DATE OF INTERVIEW 
	gen SCPamt = numeligkids * scprate if SCP==1 
	
	* Look at total cost of SCP 
	gen SCPcost = SCPamt * gross4 * 52.14 		// annual cost, grossed, in each benunit
	sum SCPcost
	local SCPcost`rep' = `r(sum)'	
	
	// LOOK AT NUMBER OF KIDS, BENUNITS RECEIVING SCP UNDER NEW METHODOLOGY 
	sum eligkid05wt if SCP==1 
	local numSCPkids05`rep' = `r(sum)'
	
	sum eligkid615wt if SCP==1
	local numSCPkids615`rep' = `r(sum)'
	
	sum eligkid015wt if SCP==1 
	local numSCPkids`rep' = `r(sum)'		
	
	sum gross4 if SCP==1 
	local numSCPbus`rep' = `r(sum)'		
	
	******************************************************************************** 
	// SAVE NEW DATA 
	********************************************************************************	

	*	Aggregate SCP variables to household level 
	bysort sernum : egen SCPhh = total(SCP) 
	replace SCPhh = (SCPhh>0 & !missing(SCPhh))

	bysort sernum : egen SCPamthh = total(SCPamt)

	bysort sernum : egen scpamt_orighh = total(scpamt_orig)

	gen scp_orighh = (scpamt_orighh>0 & !missing(scpamt_orighh))
	replace scp_orighh = (scp_orighh>0 & !missing(scp_orighh))
	
	bysort sernum : egen SCPbpamthh = total(SCPbpamt)

	*	Drop to household level data 
	bysort sernum : keep if _n==1
	unique sernum 
	assert `r(N)'==`r(unique)'		// sernum should uniquely identify observations

	*	Labels 
	label var SCPhh "Whether or not household is imputed to receive SCP"
	label var SCPamthh "Amount of SCP received by household (£/wk)"
	label var scpamt_orighh "Amount of SCP household was previously imputed to receive (old methodology)"
	label var scp_orighh "Household previously imputed as receiving SCP (old methodology)"
	label var SCPbpamthh "Amount of bridging payment received by household (£/wk)"

	keep sernum scp*hh SCPhh SCPamthh SCPbpamthh
	tempfile newscpbenunit
	save `newscpbenunit', replace 

	******************************************************************************** 
	// CALCULATE NEW POVERTY RATES IN HBAI 
	********************************************************************************	
	
	*** FOR HBAI: See harmonised dataset income variable derivation excel file in documentation to trace how income is calc'd 
	* To construct SPI'd, deflated + equivalised household income, need: bhcdef, eqobhchh, esninchh

	* Open HBAI data and merge in data created above 
	use "${projdir}\data\HBAI\i2123e_2223prices.dta", clear 
	rename *, lower
	keep if year==29
	keep sernum benunit person eqoahchh eqobhchh low*ahc* low*bhc* gs_* s_oe_*hc *hcdef eqo*hchh esahchh esninchh entinchh es_hcost gvtregn low70*hc_mdch abs1011*hc_inyr		// limit variables to make it easier to navigate 
	merge m:1 sernum using `newscpbenunit', gen(_mbu)
	assert _mbu!=2 | SCPhh==0 | scp_orighh==0 	// any non-matches from using should not be those imputed as receiving SCP
	drop if _mbu==2 
	drop _mbu
	order sernum benunit person *

	* Check that SCP (old and new) amounts come through for everyone in the hh	
	* If came through ok, then the value for each person should = mean value 
	bysort sernum : egen meanSCPamthh = mean(SCPamthh)
	bysort sernum : egen meanSCPoldamthh = mean(scpamt_orighh)
	assert meanSCPamthh == SCPamthh
	assert meanSCPoldamthh == scpamt_orighh
	drop meanSCP*

	* Get net change in income from change to SCP methodology + accounting for bridging payments
	replace SCPbpamthh = 0 if missing(SCPbpamthh)				// handle missing values of SCPbpamthh
	gen affected = (SCPhh==1 | scp_orighh==1 | SCPbpamthh>0)		// get binary for households affected by the methodology change - either old or new receivers (or both)
	gen netSCP = SCPamthh + SCPbpamthh - scpamt_orighh 
	replace netSCP = 0 if affected!=1		// helps with later changes to income 

	* Calculate new household income
	assert esninchh == entinchh if affected==1		// check that SPI adjustment does not apply to any hhs affected by SCP methods
	gen esninchh_new = esninchh + netSCP 							// add net change to SCP income to SPI'd, unequivalised, un-deflated household income 

	* Recalculate s_oe_*hc for affected households
	gen s_oe_bhc_new = esninchh_new * (bhcdef / eqobhchh) if affected==1
	gen s_oe_ahc_new = (esninchh_new - es_hcost) * (ahcdef / eqoahchh) if affected==1
	assert !missing(s_oe_bhc_new) & !missing(s_oe_ahc_new) if affected==1

	* Replace new household income with old income if not affected by methodology change
	replace s_oe_bhc_new = s_oe_bhc if affected!=1
	replace s_oe_ahc_new = s_oe_ahc if affected!=1
	
	* Examine who changes net income, how close they are to the poverty line, etc. 
	count if affected==1 & netSCP==0 & person==1 		// # sample households affected with no change in SCP income 
	local numnetSCP0_`rep' = `r(N)'
	count if affected==1 & netSCP<0 & person==1 		// # sample households affected with negative change in SCP income 
	local numnetSCPneg_`rep' = `r(N)'
	count if affected==1 & netSCP>0 & person==1 		// # sample households affected with positive change in SCP income 
	local numnetSCPpos_`rep' = `r(N)'
	sum netSCP if affected==1 & netSCP>0 & person==1 	// mean change in SCP income for people gaining from methodology change 
	local avgain_`rep' = `r(mean)'
	sum netSCP if affected==1 & netSCP<0 & person==1 	// mean change in SCP income for people losing from methodology change
	local avloss_`rep' = `r(mean)'
	
	forvalues p = 50(10)70 {
		foreach hc in bhc ahc {
			count if affected==1 & netSCP>0 & person==1 & low`p'`hc'==1
			local numpov`p'`hc'pos_`rep' = `r(N)'	
			
			count if affected==1 & netSCP<0 & person==1 & low`p'`hc'==1
			local numpov`p'`hc'neg_`rep' = `r(N)'
		}
	}
	
	* Declare poverty lines based on published stats 
	local medhhincbhc = 621 
	local medhhincahc = 545

	forvalues p = 50(10)70 {
		foreach hc in bhc ahc {
			gen pline`p'_`hc' = round((`p'/100)*`medhhinc`hc'', 1)
		}
	}

	* Generate poverty indicators (BHC, AHC; 50/60/70% of median) 
	forvalues p = 50(10)70 {
		foreach hc in bhc ahc {
			* Relative poverty
			gen pov`p'_`hc' = (s_oe_`hc'_new < pline`p'_`hc')
			replace pov`p'_`hc' = low`p'`hc' if affected!=1		// using original poverty lines, so don't let poverty status change for those not affected by methodology change
			unique sernum if pov`p'_`hc' != low`p'`hc'
			local Nchange = `r(unique)'
			unique sernum if pov`p'_`hc' != low`p'`hc' & affected==1
			
			gen chpov`p'_`hc' = low`p'`hc' - pov`p'_`hc'	// subtract new poverty flag from old one to look at changes in status
			count if chpov`p'_`hc'==-1 & person==1			 // count how many households move into poverty from methodology change
			local nintopov`p'`hc'`rep' = `r(N)'
			count if chpov`p'_`hc'==1 & person==1 			// count how many households move out of poverty from methodology change 
			local noutpov`p'`hc'`rep' = `r(N)'
			
			* Absolute poverty 
			gen apov`p'_`hc' = (s_oe_`hc'_new < round((`p'/100)*abs1011`hc'_inyr, 1))	// compare to some % of abs poverty line (contemp prices)
			replace apov`p'_`hc' = low`p'`hc'abs if affected!=1 	// using original poverty lines, so don't let poverty status change for those not affected by methodology change
		}
	}
	
	* Generate material deprivation indicators (BHC, AHC) 
	foreach hc in bhc ahc {
		gen md_`hc' = (s_oe_`hc'_new < pline70_`hc' & low70`hc'_mdch==1)		// material deprivation responses don't change; only count people in MD before whose new income is still below povline
	}


	* Calculate child poverty rates for Scotland (absolute, relative; BHC, AHC; 50/60/70% of median) 
	forvalues p = 50(10)70 {
		foreach hc in bhc ahc {
			preserve 
				keep if gvtregn==12
				collapse (mean) rpov = pov`p'_`hc' apov = apov`p'_`hc' [fw = gs_indch]
				local rpovrate`p'`hc'`rep' = 100*rpov[1]
				local rpovrateslist`p'`hc' = `rpovrateslist`p'`hc'' + `rpovrate`p'`hc'`rep''		// get sum of rel poverty rates for later average rate calculation
				local apovrate`p'`hc'`rep' = 100*apov[1]
				local apovrateslist`p'`hc' = `apovrateslist`p'`hc'' + `apovrate`p'`hc'`rep''		// same as above for abs pov rates
			restore 
		}
	}
	
	* Calculate material deprivation rates for Scotland (BHC, AHC)
	foreach hc in bhc ahc {
		preserve 
			keep if gvtregn==12 
			collapse (mean) md = md_`hc' mdorig = low70`hc'_mdch [fw = gs_indch]
			local mdrate`hc'`rep' = 100*md[1]
			local mdrateslist`hc' = `mdrateslist`hc'' + `mdrate`hc'`rep''			// get sum of material deprivation for later average rate calculation
			local mdrateorig`hc' = 100*mdorig[1]		// store published rate for later 
			
		restore 
	}
	
}

******************************************************************************** 
// OUTPUT RESULTS 
********************************************************************************

* Loop through relative and absolute poverty results
foreach t in a r {
	* Set up matrix
	mat `t'povrates = J(6, 3, 1)
	
	* Get average of poverty rate measures across all repetitions
	local row = 1 
	forvalues p = 50(10)70 {
		foreach hc in bhc ahc {
			matrix `t'povrates[`row', 1] = `row'
			matrix `t'povrates[`row', 2] = ``t'povrateslist`p'`hc''/$reps
			local ++row
		}
	}
}

* Compare to original poverty rates 
local row = 1 
forvalues p = 50(10)70 {
	foreach hc in bhc ahc {
		preserve 
			keep if gvtregn == 12 
			collapse (mean) rpov = low`p'`hc' apov = low`p'`hc'abs [fw = gs_indch]
			matrix apovrates[`row', 3] = 100*apov[1]
			matrix rpovrates[`row', 3] = 100*rpov[1]
		restore 
		local ++row
	}
}

* Export results table to Excel 
foreach t in a r {
	svmat `t'povrates, n(matcol) 	// add matrix to dataset 
	keep `t'povrates*			// keep only matrix columns
	cap drop in 7/l
	rename `t'povrates* *
	rename c1 povdef 
	rename c2 newrate 
	rename c3 origrate 

	label def povdef 1 "50% BHC" 2 "50% AHC" 3 "60% BHC" 4 "60% AHC" 5 "70% BHC" 6 "70% AHC", replace
	label val povdef povdef 

	label var povdef "Definition of poverty"
	label var newrate "Re-calculated child poverty rate" 
	label var origrate "Original child poverty rate"

	order povdef origrate newrate 
	if "`t'"=="a" {
		export excel using "${projdir}\out\ImputationResults.xlsx", firstrow(varlabels) sheet("Abs poverty rates", replace)
	}
	else {
		export excel using "${projdir}\out\ImputationResults.xlsx", firstrow(varlabels) sheet("Rel poverty rates", replace)
	}
}

* Get average of material deprivation rate measures across all repetitions
foreach hc in bhc ahc {
	noi di "Average material deprivation rate across $reps repetitions (`hc'): " %6.2f `mdrateslist`hc''/$reps
	noi di "Published material deprivation rate (`hc'): " %6.2f `mdrateorig`hc''
}

* Display estimated cost, # children, # households receiving SCP under old imputation 
noi di "Estimated cost of SCP in 2022-23 (old method): " %10.2f `scp_cost_orig'/1000000 " million."
noi di "Estimated number of children (0-19) receiving SCP in 2022-23 (old method): " %10.0f `scp_kids_orig' "."
noi di "Estimated number of benunits receiving SCP in 2022-23 (old method): " %10.0f `scp_bus_orig' "."

* Get average of costs 
clear 
set obs $reps 
gen costest = . 
forvalues row = 1/$reps {
	replace costest = `SCPcost`row'' in `row'
}
sum costest
noi di "Estimated cost of SCP in 2022-23 (# reps = $reps): " %10.2f `r(mean)'/1000000 " million."

* Get average number of children in receipt 
clear 
set obs $reps 
gen numkids = .
gen numkids05 = . 
gen numkids615 = .
forvalues row = 1/$reps {
	replace numkids = `numSCPkids`row'' in `row'
	replace numkids05 = `numSCPkids05`row'' in `row'
	replace numkids615 = `numSCPkids615`row'' in `row'
}
sum numkids 
noi di "Estimated number of children (0-15) receiving SCP in 2022-23 (# reps = $reps): " %10.1f `r(mean)' "."
sum numkids05 
noi di "Estimated number of children (0-5) receiving SCP in 2022-23 (# reps = $reps): " %10.1f `r(mean)' "."
sum numkids615 
noi di "Estimated number of children (6-15) receiving SCP in 2022-23 (# reps = $reps): " %10.1f `r(mean)' "."

* Get average number of benunits in receipt 
clear 
set obs $reps
gen numbus = . 
forvalues row = 1/$reps {
	replace numbus = `numSCPbus`row'' in `row'
}
sum numbus 
noi di "Estimated number of benunits receiving SCP in 2022-23 (# reps = $reps): " %10.1f `r(mean)' "."

* Get averages of num sample households affected by SCP changes 
clear 
set obs $reps 
foreach var in 0 pos neg {
	gen numnetSCP`var' = . 
	forvalues row = 1/$reps {
		replace numnetSCP`var' = `numnetSCP`var'_`row'' in `row'
	}
	sum numnetSCP`var' 
	local avnetSCP`var' = `r(mean)'
	noi di "Average number of sample households with `var' net change in SCP income: " %10.1f `avnetSCP`var'' "."
} 

* Get averages of number of gainers, losers; loss/gain from SCP changes 
clear 
set obs $reps 
foreach var in gain loss {
	gen av`var' = . 
	forvalues row = 1/$reps {
		replace av`var' = `av`var'_`row'' in `row'
	}
	sum av`var'
	local av`var' = `r(mean)'		// save for outputting to Excel below
	noi di "Average `var' to household income (unequivalised) due to methodology change: " %10.2f `av`var'' "."
}

clear 
set obs $reps
forvalues p = 50(10)70 {
	foreach hc in bhc ahc {
		foreach var in pos neg {
			gen `var'ch_pov`p'`hc' = . 
			forvalues row = 1/$reps {
				replace `var'ch_pov`p'`hc' = `numpov`p'`hc'`var'_`row'' in `row'
			}
		}
	}
}

forvalues p = 50(10)70 {
	foreach hc in bhc ahc {
		gen intopov`p'`hc' = . 
		gen outpov`p'`hc' = . 
		forvalues row = 1/$reps {
			replace intopov`p'`hc' = `nintopov`p'`hc'`row'' in `row'
			replace outpov`p'`hc' = `noutpov`p'`hc'`row'' in `row'
		}
	}
}

collapse (mean) *pov*
gen n=1
rename pos* *1
rename neg* *0
rename into* *2
rename out* *3
reshape long ch_pov50bhc ch_pov50ahc ch_pov60bhc ch_pov60ahc ch_pov70bhc ch_pov70ahc pov50bhc pov50ahc pov60bhc pov60ahc pov70bhc pov70ahc, i(n) j(direction)
forvalues p = 50(10)70 {
	foreach hc in bhc ahc {
		replace pov`p'`hc' = ch_pov`p'`hc' in 1/2
		drop ch_pov`p'`hc'
	}
}
label def direction 0 "In poverty (Negative net SCP)" 1 "In poverty (Positive net SCP)" 2 "Moves into poverty" 3 "Moves out of poverty" 4 "Total (Negative net SCP)" 5 "Total (Positive net SCP)" 6 "Total (Net neutral SCP)" 7 "Average net negative change (losers)" 8 "Average net positive gain (gainers)"
label val direction direction
drop n 

set obs 9
replace direction = _n-1 in 5/9	// Make "total" rows 
ds pov*
foreach var in `r(varlist)' {
	replace `var' = `avnetSCP0' in 7
	replace `var' = `avnetSCPpos' in 6
	replace `var' = `avnetSCPneg' in 5
	replace `var' = `avgain' in 9
	replace `var' = `avloss' in 8
}

}

log close

